@@ -12,8 +12,7 @@
 #See the License for the specific language governing permissions and
 #limitations under the License.
 #
+CONFIGFILE = 'config.cfg'
 # Path to look up cookbooks
 cookbook_paths = ['site-cookbooks', 'cookbooks']
-
-# Node's Chef Solo working directory for storing cookbooks, roles, etc.
 node_work_path = '/tmp/chef-solo'
