@@ -22,7 +22,7 @@ from fabric.contrib.files import append, exists, upload_template
 from fabric.utils import abort
 
 from littlechef.lib import credentials
-from littlechef.settings import node_work_path, cookbook_paths
+from littlechef.settings import cookbook_paths
 from littlechef import LOGFILE as logging_path
 
 
@@ -56,21 +56,21 @@ def configure(current_node=None):
     current_node = current_node or {}
     with credentials():
         # Ensure that the /tmp/chef-solo/cache directory exist
-        cache_dir = "{0}/cache".format(node_work_path)
+        cache_dir = "{0}/cache".format(env.node_work_path)
         if not exists(cache_dir):
             with settings(hide('running', 'stdout'), warn_only=True):
                 output = sudo('mkdir -p {0}'.format(cache_dir))
             if output.failed:
-                error = "Could not create {0} dir. ".format(node_work_path)
+                error = "Could not create {0} dir. ".format(env.node_work_path)
                 error += "Do you have sudo rights?"
                 abort(error)
         # Change ownership of /tmp/chef-solo/ so that we can rsync
         with hide('running', 'stdout'):
             with settings(warn_only=True):
                 output = sudo(
-                    'chown -R {0} {1}'.format(env.user, node_work_path))
+                    'chown -R {0} {1}'.format(env.user, env.node_work_path))
             if output.failed:
-                error = "Could not modify {0} dir. ".format(node_work_path)
+                error = "Could not modify {0} dir. ".format(env.node_work_path)
                 error += "Do you have sudo rights?"
                 abort(error)
         # Set up chef solo configuration
@@ -82,10 +82,10 @@ def configure(current_node=None):
         reversed_cookbook_paths = cookbook_paths[:]
         reversed_cookbook_paths.reverse()
         cookbook_paths_list = '[{0}]'.format(', '.join(
-            ['"{0}/{1}"'.format(node_work_path, x) \
+            ['"{0}/{1}"'.format(env.node_work_path, x) \
                 for x in reversed_cookbook_paths]))
         data = {
-            'node_work_path': node_work_path,
+            'node_work_path': env.node_work_path,
             'cookbook_paths_list': cookbook_paths_list,
             'environment': current_node.get('chef_environment', '_default'),
             'verbose': "true" if env.verbose else "false"
@@ -153,7 +153,7 @@ def check_distro():
 def _gem_install():
     """Install Chef from gems"""
     # Install RubyGems from Source
-    rubygems_version = "1.7.2"
+    rubygems_version = "1.8.10"
     run('wget http://production.cf.rubygems.org/rubygems/rubygems-{0}.tgz'
         .format(rubygems_version))
     run('tar zxf rubygems-{0}.tgz'.format(rubygems_version))
@@ -177,7 +177,7 @@ def _gem_apt_install():
 def _gem_rpm_install():
     """Install Chef from gems for rpm based distros"""
     _add_rpm_repos()
-    needed_packages = "ruby ruby-shadow gcc gcc-c++ ruby-devel wget rsync"
+    needed_packages = "make ruby ruby-shadow gcc gcc-c++ ruby-devel wget rsync"
     with show('running'):
         sudo('yum -y install {0}'.format(needed_packages))
     _gem_install()
@@ -281,7 +281,7 @@ def _add_rpm_repos():
 
     epel_release = "epel-release-5-4.noarch"
     if rhel_version == "6":
-        epel_release = "epel-release-6-5.noarch"
+        epel_release = "epel-release-6-7.noarch"
     with show('running'):
         # Install the EPEL Yum Repository.
         with settings(hide('warnings', 'running'), warn_only=True):
